@@ -1,6 +1,8 @@
 describe.logit.net<-function(){
 category <- "dichotomous"
 description  <- "Social Network Logistic Regression for Dichotomous Dependent Variables"
+authors <- c("Skyler J. Cranmer")
+year <- 2007
 package <-list(	name 	="sna",
 		version	="1.4"
 		)
@@ -11,5 +13,5 @@ parameters$pi<-list(equations=c(1,1),
 			expVar=TRUE
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
