@@ -1,6 +1,8 @@
 describe.tobit.bayes<-function(){
 category <- "continuous"
 description  <- "Bayesian Linear Regression for a Censored Dependent Variable"
+authors <- c("Ben Goodrich","Ying Lu")
+year <- 2007
 package <-list(	name 	="MCMCpack",
 		version	="0.6"
 		)
@@ -11,5 +13,5 @@ parameters$mu<-list(equations=c(1,1),
 			expVar=TRUE
 			)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
