@@ -1,6 +1,6 @@
-names.zelig.relogit <- function (object, ...) {
-   res <- names.default(object, ...)[1:5]
-   qi.names <- names.default(object$qi, ...)
+names.zelig.relogit <- function(x) {
+   res <- names(unclass(x))[1:5]
+   qi.names <- names(x$qi)
    for (i in 1:length(qi.names)) {
      qi.names[i] <- paste("qi$", qi.names[i], sep = "")
   }
